@@ -31,6 +31,7 @@ class ARFPlot:
 
         self._attr_name = PassiveVariable(attr_name, 'Name of attribute')
         self._x_values = PassiveVariable(x_values, 'Name of attribute')
+
         # the callable is not important; we want to use the dependency logic of
         # the ActiveVariable and we are not actually interested in the value
         self._needs_computation = ActiveVariable(
@@ -79,7 +80,8 @@ class ARFPlot:
         self, *solutions: BaseARF,
         multicore: bool = False
     ) -> None:
-        """Add solutions to list of solutions for plotting
+        """Add solutions to list of solutions for plotting e.g.
+        :class:`osaft.king1934.ARF()`
 
         :param solutions: one or multiple solutions,
                e.g. :class:`osaft.king1934.ARF()`
@@ -98,7 +100,8 @@ class ARFPlot:
                     f'attribute `name` of this solution({solution}).',
                 )
             self._solutions[solution.name] = ARFData(
-                solution, multicore=multicore,
+                solution,
+                multicore=multicore,
             )
 
     def remove_solution(self, solution: BaseARF) -> None:
