@@ -168,8 +168,8 @@ class ChangingNumber(BaseChangingVariable):
     def low(self, value: Union[int, float]) -> None:
         if self.high is not None and value > self.high:
             raise ValueError(
-                f'high (= {value}) needs to be larger than low '
-                f'(= {self.low})',
+                f'low (= {value}) needs to be smaller than high '
+                f'(= {self.high})',
             )
         elif value > self.value:
             self._low = value
@@ -516,7 +516,7 @@ class BaseTest(NumericTestCase):
 
         :param dict_of_methods: dict of methods and additional arguments to be
             tested
-        :param n_end: n in [0, 1, ..., n_end]; tested in reversed order
+        :param n_end: n in [0, 1, ..., n_end]
         :param threshold: comparing threshold for the whole dict
         :param threshold: value below which test values are assumed to be zero
         """
@@ -532,13 +532,13 @@ class BaseTest(NumericTestCase):
                     else:
                         arg = (n, args)
                 else:
-                    arg = (n,)
+                    arg = n
 
                 with self.subTest(method=method, arguments=arg):
                     self.do_testing(
                         func_1=func_1, args_1=arg,
                         func_2=func_2, args_2=arg,
-                        threshold=threshold,
+                        threshold=threshold, zero=zero,
                     )
 
     # -------------------------------------------------------------------------
@@ -599,7 +599,7 @@ class BaseTest(NumericTestCase):
 
     @zeta_s.setter
     def zeta_s(self, value: float) -> None:
-        self._eta_s.value = value
+        self._zeta_s.value = value
 
     @property
     def rho_s(self) -> float:
